@@ -1,21 +1,21 @@
 #!/usr/bin/env python
 #
 # Author: Mike McKerns (mmckerns @caltech and @uqfoundation)
-# Copyright (c) 2018-2022 The Uncertainty Quantification Foundation.
+# Copyright (c) 2018-2023 The Uncertainty Quantification Foundation.
 # License: 3-clause BSD.  The full license text is available at:
 #  - https://github.com/uqfoundation/dill/blob/master/LICENSE
 
-from __future__ import print_function
 import glob
 import os
+import sys
+import subprocess as sp
+python = sys.executable
 try:
     import pox
-    python = pox.which_python(version=True, fullpath=False) or 'python'
+    python = pox.which_python(version=True) or python
 except ImportError:
-    python = 'python'
-import subprocess as sp
-from sys import platform
-shell = platform[:3] == 'win'
+    pass
+shell = sys.platform[:3] == 'win'
 
 suite = os.path.dirname(__file__) or os.path.curdir
 tests = glob.glob(suite + os.path.sep + 'test_*.py')
@@ -23,8 +23,13 @@ tests = glob.glob(suite + os.path.sep + 'test_*.py')
 
 if __name__ == '__main__':
 
+    failed = 0
     for test in tests:
         p = sp.Popen([python, test], shell=shell).wait()
-        if not p:
-            print('.', end='')
+        if p:
+            print('F', end='', flush=True)
+            failed = 1
+        else:
+            print('.', end='', flush=True)
     print('')
+    exit(failed)
